Exception - 异常
================

..  inheritance-diagram:: zhihu_oauth.exception
    :parts: 1

..  automodule:: zhihu_oauth.exception
    :members:
    :undoc-members:
    :special-members: __init__
